translate.misc.typecheck.Single

Package translate :: Package misc :: Package typecheck :: Class Single |
[hide private]
[frames] | no frames]

# Class Single

source code

Instance Methods | [hide private]
__init__(self, type) x.__init__(...) initializes x; see x.__class__.__doc__ for signature | source code
__typecheck__(self, func, to_check) | source code
__eq__(self, other) | source code
__hash__(self) hash(x) | source code
__repr__(self) str(x) | source code
Inherited from `CheckType`: `__ne__`, `__str__` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Methods | [hide private]
__typesig__(cls, obj) | source code

Class Variables | [hide private]
| name = ``'``Single``'``

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, type) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### __typecheck__(self, func, to_check) | source code
Overrides: CheckType.__typecheck__

### __eq__(self, other) (Equality operator) | source code
Overrides: CheckType.__eq__

### __hash__(self) (Hashing function) | source code
hash(x) Overrides: object.__hash__ (inherited documentation)

### __repr__(self) (Representation operator) | source code
str(x) Overrides: object.__repr__ (inherited documentation)

### __typesig__(cls, obj) Class Method | source code
Overrides: CheckType.__typesig__